@@ -1,4 +1,4 @@
-r"""Implemetation of Feature Similarity Index Measure
+r"""Implementation of Feature Similarity Index Measure
 Code is based on MATLAB version for computations in pixel domain
 https://www4.comp.polyu.edu.hk/~cslzhang/IQA/FSIM/Files/FeatureSIM.m
 References:
@@ -11,7 +11,7 @@ from typing import Union, Tuple
 import torch
 from torch.nn.modules.loss import _Loss
 
-from piq.utils import _validate_input, _reduce, _version_tuple
+from piq.utils import _validate_input, _reduce, _parse_version
 from piq.functional import ifftshift, get_meshgrid, similarity_map, gradient_map, scharr_filter, rgb2yiq
 
 
@@ -39,9 +39,9 @@ def fsim(x: torch.Tensor, y: torch.Tensor, reduction: str = 'mean',
             of the angular Gaussian function used to construct filters in the frequency plane.
         k: No of standard deviations of the noise energy beyond the mean at which we set the noise
             threshold  point, below which phase congruency values get penalized.
-        
+
     Returns:
-        Index of similarity betwen two images. Usually in [0, 1] interval.
+        Index of similarity between two images. Usually in [0, 1] interval.
         Can be bigger than 1 for predicted :math:`x` images with higher contrast than the original ones.
 
     References:
@@ -52,7 +52,7 @@ def fsim(x: torch.Tensor, y: torch.Tensor, reduction: str = 'mean',
     Note:
         This implementation is based on the original MATLAB code.
         https://www4.comp.polyu.edu.hk/~cslzhang/IQA/FSIM/FSIM.htm
-        
+
     """
     _validate_input([x, y], dim_range=(4, 4), data_range=(0, data_range))
 
@@ -127,7 +127,7 @@ def _construct_filters(x: torch.Tensor, scales: int = 4, orientations: int = 4,
                        min_length: int = 6, mult: int = 2, sigma_f: float = 0.55,
                        delta_theta: float = 1.2, k: float = 2.0):
     """Creates a stack of filters used for computation of phase congruensy maps
-    
+
     Args:
         x: Tensor. Shape :math:`(N, 1, H, W)`.
         scales: Number of wavelets
@@ -152,6 +152,9 @@ def _construct_filters(x: torch.Tensor, scales: int = 4, orientations: int = 4,
 
     # Pre-compute some stuff to speed up filter construction
     grid_x, grid_y = get_meshgrid((H, W))
+
+    # Move grid to GPU early on, so that all math heavy stuff computes faster.
+    grid_x, grid_y = grid_x.to(x), grid_y.to(x)
     radius = torch.sqrt(grid_x ** 2 + grid_y ** 2)
     theta = torch.atan2(-grid_y, grid_x)
 
@@ -174,7 +177,7 @@ def _construct_filters(x: torch.Tensor, scales: int = 4, orientations: int = 4,
     # away to zero at the boundaries.  All log Gabor filters are multiplied by
     # this to ensure no extra frequencies at the 'corners' of the FFT are
     # incorporated as this seems to upset the normalisation process when
-    lp = _lowpassfilter(size=(H, W), cutoff=.45, n=15)
+    lp = _lowpassfilter(size=(H, W), cutoff=.45, n=15).to(x)
 
     # Construct the radial filter components...
     log_gabor = []
@@ -204,7 +207,7 @@ def _construct_filters(x: torch.Tensor, scales: int = 4, orientations: int = 4,
     log_gabor = torch.stack(log_gabor)
 
     # Multiply, add batch dimension and transfer to correct device.
-    filters = (spread.repeat_interleave(scales, dim=0) * log_gabor.repeat(orientations, 1, 1)).unsqueeze(0).to(x)
+    filters = (spread.repeat_interleave(scales, dim=0) * log_gabor.repeat(orientations, 1, 1)).unsqueeze(0)
     return filters
 
 
@@ -239,8 +242,9 @@ def _phase_congruency(x: torch.Tensor, scales: int = 4, orientations: int = 4,
 
     # Fourier transform
     filters = _construct_filters(x, scales, orientations, min_length, mult, sigma_f, delta_theta, k)
-    recommended_torch_version = '1.8.0'
-    if _version_tuple(torch.__version__) >= _version_tuple(recommended_torch_version):
+    recommended_torch_version = _parse_version('1.8.0')
+    torch_version = _parse_version(torch.__version__)
+    if len(torch_version) != 0 and torch_version >= recommended_torch_version:
         imagefft = torch.fft.fft2(x)
         filters_ifft = torch.fft.ifft2(filters)
         filters_ifft = filters_ifft.real * math.sqrt(H * W)
@@ -346,17 +350,17 @@ def _lowpassfilter(size: Tuple[int, int], cutoff: float, n: int) -> torch.Tensor
     Constructs a low-pass Butterworth filter.
 
     Args:
-        size: Tuple with heigth and width of filter to construct
+        size: Tuple with height and width of filter to construct
         cutoff: Cutoff frequency of the filter in (0, 0.5()
         n: Filter order. Higher `n` means sharper transition.
             Note that `n` is doubled so that it is always an even integer.
-        
+
     Returns:
         f = 1 / (1 + w/cutoff) ^ 2n
-    
+
     Note:
         The frequency origin of the returned filter is at the corners.
-    
+
     """
     assert 0 < cutoff <= 0.5, "Cutoff frequency must be between 0 and 0.5"
     assert n > 1 and int(n) == n, "n must be an integer >= 1"
