@@ -13,7 +13,7 @@ from multiprocessing import Pool
 from warnings import warn
 
 from piq.base import BaseFeatureMetric
-from piq.utils import _validate_input, _version_tuple
+from piq.utils import _validate_input, _parse_version
 
 
 def relative(intervals: np.ndarray, alpha_max: float, i_max: int = 100) -> np.ndarray:
@@ -82,8 +82,9 @@ def lmrk_table(witnesses: np.ndarray, landmarks: np.ndarray) -> Tuple[np.ndarray
         raise ImportError("Scipy is required for computation of the Geometry Score but not installed. "
                           "Please install scipy using the following command: pip install --user scipy")
 
-    recommended_scipy_version = "1.3.3"
-    if _version_tuple(scipy.__version__) < _version_tuple(recommended_scipy_version):
+    recommended_scipy_version = _parse_version("1.3.3")
+    scipy_version = _parse_version(scipy.__version__)
+    if len(scipy_version) != 0 and scipy_version < recommended_scipy_version:
         warn(f'Scipy of version {scipy.__version__} is used while version >= {recommended_scipy_version} is '
              f'recommended. Consider updating scipy to avoid potential long compute time with older versions.')
 
@@ -115,8 +116,9 @@ def witness(features: np.ndarray, sample_size: int = 64, gamma: Optional[float]
         raise ImportError("GUDHI is required for computation of the Geometry Score but not installed. "
                           "Please install scipy using the following command: pip install --user gudhi")
 
-    recommended_gudhi_version = "3.2"
-    if _version_tuple(gudhi.__version__) < _version_tuple(recommended_gudhi_version):
+    recommended_gudhi_version = _parse_version("3.2.0")
+    gudhi_version = _parse_version(gudhi.__version__)
+    if len(gudhi_version) != 0 and gudhi_version < recommended_gudhi_version:
         warn(f'GUDHI of version {gudhi.__version__} is used while version >= {recommended_gudhi_version} is '
              f'recommended. Consider updating GUDHI to avoid potential problems.')
 
@@ -153,14 +155,13 @@ class GS(BaseFeatureMetric):
             Higher values can reduce variance, but increase computation cost.
         gamma: Parameter determining maximum persistence value. Default is ``1.0 / 128 * N_imgs / 5000``
         i_max: Upper bound on i in RLT(i, 1, X, L)
-        num_workers: Number of proccess used for GS computation.
+        num_workers: Number of processes used for GS computation.
 
     Examples:
-        >>> loss = GS()
-        >>> x = torch.rand(3, 3, 256, 256, requires_grad=True)
-        >>> y = torch.rand(3, 3, 256, 256)
-        >>> output = loss(x, y)
-        >>> output.backward()
+        >>> gs_metric = GS()
+        >>> x_feats = torch.rand(10000, 1024)
+        >>> y_feats = torch.rand(10000, 1024)
+        >>> gs: torch.Tensor = gs_metric(x_feats, y_feats)
 
     References:
         Khrulkov V., Oseledets I. (2018).
@@ -210,10 +211,10 @@ class GS(BaseFeatureMetric):
 
     def _relative_living_times(self, idx: int) -> Union[np.ndarray, np.ndarray, np.ndarray]:
         r"""Implements Algorithm 1 for two samples of landmarks.
-    
+
         Args:
             idx : Dummy argument. Used for multiprocessing.Pool to work correctly
-        
+
         Returns:
             An array of size (i_max, ) containing RLT(i, 1, X, L)
             for randomly sampled landmarks.
