@@ -1,4 +1,4 @@
-r"""Implemetation of Visual Saliency-induced Index
+r"""Implementation of Visual Saliency-induced Index
 Code is based on the MATLAB version for computations in pixel domain
 https://sse.tongji.edu.cn/linzhang/IQA/VSI/VSI.htm
 
@@ -14,7 +14,7 @@ from torch.nn.modules.loss import _Loss
 from torch.nn.functional import avg_pool2d, interpolate, pad
 
 from piq.functional import ifftshift, gradient_map, scharr_filter, rgb2lmn, rgb2lab, similarity_map, get_meshgrid
-from piq.utils import _validate_input, _reduce, _version_tuple
+from piq.utils import _validate_input, _reduce, _parse_version
 
 
 def vsi(x: torch.Tensor, y: torch.Tensor, reduction: str = 'mean', data_range: Union[int, float] = 1.,
@@ -63,8 +63,8 @@ def vsi(x: torch.Tensor, y: torch.Tensor, reduction: str = 'mean', data_range: U
                       'the grey channel 3 times.')
 
     # Scale to [0, 255] range to match scale of constant
-    x = x * 255. / data_range
-    y = y * 255. / data_range
+    x = x * 255. / float(data_range)
+    y = y * 255. / float(data_range)
 
     vs_x = sdsp(x, data_range=255, omega_0=omega_0,
                 sigma_f=sigma_f, sigma_d=sigma_d, sigma_c=sigma_c)
@@ -204,7 +204,7 @@ def sdsp(x: torch.Tensor, data_range: Union[int, float] = 255, omega_0: float =
     Returns:
         torch.Tensor: Visual saliency map
     """
-    x = x / data_range * 255
+    x = x / float(data_range) * 255
     size = x.size()
     size_to_use = (256, 256)
     x = interpolate(input=x, size=size_to_use, mode='bilinear', align_corners=False)
@@ -212,8 +212,9 @@ def sdsp(x: torch.Tensor, data_range: Union[int, float] = 255, omega_0: float =
     x_lab = rgb2lab(x, data_range=255)
 
     lg = _log_gabor(size_to_use, omega_0, sigma_f).to(x).view(1, 1, *size_to_use)
-    recommended_torch_version = '1.8.0'
-    if _version_tuple(torch.__version__) >= _version_tuple(recommended_torch_version):
+    recommended_torch_version = _parse_version('1.8.0')
+    torch_version = _parse_version(torch.__version__)
+    if len(torch_version) != 0 and torch_version >= recommended_torch_version:
         x_fft = torch.fft.fft2(x_lab)
         x_ifft_real = torch.fft.ifft2(x_fft * lg).real
     else:
